@@ -1,10 +1,11 @@
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Run; # git description: 0.033-4-g1bba54f
+package Dist::Zilla::Plugin::Run; # git description: 0.034-8-g6dde0d5
 # ABSTRACT: Run external commands and code at specific phases of Dist::Zilla
+# KEYWORDS: plugin tool distribution build release run command shell execute
 
-our $VERSION = '0.034';
+our $VERSION = '0.035';
 
 #pod =head1 SYNOPSIS
 #pod
@@ -135,7 +136,7 @@ Dist::Zilla::Plugin::Run - Run external commands and code at specific phases of
 
 =head1 VERSION
 
-version 0.034
+version 0.035
 
 =head1 SYNOPSIS
 
@@ -286,7 +287,7 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Randy Stauner Torsten Raudssus Nickolay Platonov Olivier Mengué Al Newkirk Tatsuhiko Miyagawa Thomas Sibley
+=for stopwords Karen Etheridge Randy Stauner Nickolay Platonov Olivier Mengué Al Newkirk Tatsuhiko Miyagawa Thomas Sibley David Golden
 
 =over 4
 
@@ -300,10 +301,6 @@ Randy Stauner <rwstauner@cpan.org>
 
 =item *
 
-Torsten Raudssus <getty@cpan.org>
-
-=item *
-
 Nickolay Platonov <nplatonov@cpan.org>
 
 =item *
@@ -322,6 +319,10 @@ Tatsuhiko Miyagawa <miyagawa@cpan.org>
 
 Thomas Sibley <tsibley@cpan.org>
 
+=item *
+
+David Golden <dagolden@cpan.org>
+
 =back
 
 =cut
